@@ -14,7 +14,7 @@ use File::Path;
 use XML::Simple;
 use Sys::Hostname;
 
-our $VERSION = '2.0';
+our $VERSION = '2.0.1';
 $ENV{LC_ALL} = 'C'; # Turn off localised output for commands
 $ENV{LANG} = 'C'; # Turn off localised output for commands
 
@@ -146,7 +146,7 @@ sub new {
   
         });
 
-    $logger->debug("OCS Agent initialised");
+    $logger->debug("FusionInventory Agent initialised");
 
     bless $self;
 
