@@ -5,6 +5,18 @@ use File::Path;
 use strict;
 use warnings;
 
+use Config;
+
+BEGIN {
+  # threads and threads::shared must be load before
+  # $lock is initialized
+  if ($Config{usethreads}) {
+    if (!eval "use threads;1;" || !eval "use threads::shared;1;") {
+      print "[error]Failed to use threads!\n"; 
+    }
+  }
+}
+
 # resetNextRunDate() can also be call from another thread (RPC)
 my $lock : shared;
 
@@ -210,10 +222,6 @@ sub getNextRunDate {
 
     lock($lock);
 
-    # Only for server mode
-    return 1 if $self->{'type'} ne 'server';
-
-
     if (${$self->{'nextRunDate'}}) {
       
         if ($self->{debugPrintTimer} < time) {
